@@ -7,6 +7,7 @@ use Geo::OSM::Tiles qw( :all );
 use LWP::UserAgent;
 use File::Path;
 use File::Basename;
+use File::Spec;
 use Cwd qw(cwd);
 use Getopt::Long;
 
@@ -138,7 +139,8 @@ sub downloadtile
     my ($lwpua, $tilex, $tiley, $zoom) = @_;
     my $path = tile2path($tilex, $tiley, $zoom);
     my $url = "$baseurl/$path";
-    my $fname = "$destdir/$path";
+    my @pathcomp = split /\//, $path;
+    my $fname = File::Spec->catfile($destdir, @pathcomp);
 
     mkpath(dirname($fname));
     my $res = $lwpua->get($url, ':content_file' => $fname);
@@ -300,11 +302,11 @@ L<http://wiki.openstreetmap.org/wiki/Slippy_Map>
 
 =head1 AUTHOR
 
-Rolf Krahl E<lt>rolf@rotkraut.deE<gt>
+Rolf Krahl E<lt>rotkraut@cpan.orgE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2008 by Rolf Krahl
+Copyright (C) 2008-2010 by Rolf Krahl
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
